@@ -5,7 +5,7 @@ use SOAP::WSDL::XSD::Schema::Builtin;
 use Class::Std::Fast::Storable;
 use base qw(SOAP::WSDL::Base);
 
-use version; our $VERSION = qv('2.00.99_1');
+use version; our $VERSION = qv('2.00.99_2');
 
 my %schema_of :ATTR(:name<schema> :default<[]>);
 
@@ -18,6 +18,7 @@ sub START {
 sub find_type {
     my ($self, $ns, $name) = @_;
     ($ns, $name) = @{ $ns } if ref $ns;     # allow passing list refs
+    print "Looking for type {$ns}$name\n" if ($SOAP::WSDL::Trace);
     foreach my $schema (@{ $schema_of{ ident $self } }) {
         my $type = $schema->find_type($ns, $name);
         return $type if $type;
@@ -28,6 +29,7 @@ sub find_type {
 sub find_attribute {
     my ($self, $ns, $name) = @_;
     ($ns, $name) = @{ $ns } if ref $ns;     # allow passing list refs
+    print "Looking for attribute {$ns}$name\n" if ($SOAP::WSDL::Trace);
     foreach my $schema (@{ $schema_of{ ident $self } }) {
         my $type = $schema->find_attribute($ns, $name);
         return $type if $type;
@@ -38,7 +40,9 @@ sub find_attribute {
 sub find_element {
     my ($self, $ns, $name) = @_;
     ($ns, $name) = @{ $ns } if ref $ns;     # allow passing list refs
+    print "Looking for element {$ns}$name\n" if ($SOAP::WSDL::Trace);
     foreach my $schema (@{ $schema_of{ ident $self } }) {
+        print "\tin schema ", $schema->get_targetNamespace() ,"\n" if ($SOAP::WSDL::Trace);
         my $type = $schema->find_element($ns, $name);
         return $type if $type;
     }
